@@ -5,9 +5,8 @@ use utf8;
 
 package Neo4j::Driver::Transport::HTTP;
 # ABSTRACT: Adapter for the Neo4j Transactional HTTP API
-$Neo4j::Driver::Transport::HTTP::VERSION = '0.12_02'; # TRIAL
+$Neo4j::Driver::Transport::HTTP::VERSION = '0.10';
 
-$Neo4j::Driver::Transport::HTTP::VERSION = '0.1202';
 use Carp qw(carp croak);
 our @CARP_NOT = qw(Neo4j::Driver::Transaction);
 use Try::Tiny;
@@ -33,17 +32,6 @@ our $SERVICE_ROOT_ENDPOINT = '/db/data/';
 sub new {
 	my ($class, $driver) = @_;
 	
-	my $self = bless {
-		die_on_error => $driver->{die_on_error},
-	}, $class;
-	
-	# If the Driver object knows how to create the REST client,
-	# we'll follow its lead. This is useful for testing.
-	if ($driver->{client_factory}) {
-		$self->{client} = $driver->{client_factory}->();
-		return $self;
-	}
-	
 	my $uri = $driver->{uri};
 	if ($driver->{auth}) {
 		croak "Only HTTP Basic Authentication is supported" if $driver->{auth}->{scheme} ne 'basic';
@@ -59,9 +47,11 @@ sub new {
 	$client->addHeader('Accept', $CONTENT_TYPE);
 	$client->addHeader('Content-Type', $CONTENT_TYPE);
 	$client->addHeader('X-Stream', 'true');
-	$self->{client} = $client;
 	
-	return $self;
+	return bless {
+		client => $client,
+		die_on_error => $driver->{die_on_error},
+	}, $class;
 }
 
 
@@ -93,7 +83,7 @@ sub run {
 	$coder = $coder->pretty->sort_by(sub {
 		return -1 if $JSON::PP::a eq 'statements';
 		return 1 if $JSON::PP::b eq 'statements';
-		return $JSON::PP::a cmp $JSON::PP::b;  # Neo4j doesn't care, but our testing sim does
+		return 0;  # $JSON::PP::a cmp $JSON::PP::b;
 	});
 	
 	my $response = $self->_request($tx, 'POST', $coder->encode($request));
@@ -241,7 +231,7 @@ Neo4j::Driver::Transport::HTTP - Adapter for the Neo4j Transactional HTTP API
 
 =head1 VERSION
 
-version 0.12_02
+version 0.10
 
 =head1 DESCRIPTION
 
